==> hexalate_1.0.2.orig.tar.bz2: hexalate-1.0.2/translations/hexalate_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Küsimus</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>Katkestada praegune mäng?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Vali rakenduse keel:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Süsteemi keel&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Märkus</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Keele muudatuse mõjumiseks taaskäivita palun see programm.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Korras</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Vabandust</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Eelmise mängu laadimine ebaõnnestus. Uue mängu alustamine.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="34"/>
        <location filename="../src/window.cpp" line="75"/>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;Game</source>
        <translation>Mäng</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>&amp;New</source>
        <translation>Uus</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="42"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>&amp;Quit</source>
        <translation>Lõpeta</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="44"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>&amp;Settings</source>
        <translation>&amp;Seaded</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="47"/>
        <source>Application &amp;Language...</source>
        <translation>Rakendus ja keel...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;Help</source>
        <translation>Abiinfo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>&amp;About</source>
        <translation>Rakendusest</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="51"/>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt info</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>About Hexalate</source>
        <translation>Hexalate info</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>A color matching game</source>
        <translation>Värvide sobitamise mäng</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autoriõigused &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Antud välja &lt;a href=%1&gt;GPL 3&lt;/a&gt; litsentsi alusel</translation>
    </message>
</context>
</TS>

==> hexalate-1.2.5.tar.bz2: hexalate-1.2.5/translations/hexalate_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Küsimus</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Kas katkestame praeguse mängu?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vali rakenduse keel:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Süsteemi keel&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Märkus</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Keele muudatuse mõjumiseks taaskäivita palun see rakendus.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Korras</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Vabandust</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Eelmise mängu laadimine ei õnnestunud. Alustame uut mängu.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Män&amp;g</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Uus</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Välju</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Seadistused</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Rakendus ja keel...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Abiteave</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>R&amp;akenduse teave</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt teave</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation>Hexalate&apos;i teave</translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation>Värvide sobitamise mäng</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autoriõigused &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Avaldatud &lt;a href=%1&gt;GPL 3&lt;/a&gt; litsentsi alusel</translation>
    </message>
</context>
</TS>
